Package dung de inference model yolov5 voi custom object
# Install
```bash
pip install yolov5_inference
```

# Use
```bash
model = yolov5_inference(weights='../path/of/weights')
img_path = '../path/of/img'
rs = model.detect(img_path)
```
